@@ -15,11 +15,10 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 #                                                                # 
-# last changed in version = '3.2-1'                              #
+# last changed in version = '4.1-1'                              #
 #                                                                # 
 ##################################################################
 
-pathReaver=/home/user/.reaver
 tempLogging=/tmp/cleven.log
 
 [ "$(whoami)" != 'root' ] && ( echo you are using a non-privileged account; exit 1 )
@@ -59,8 +58,8 @@ if [ "$1" == 'getWlanInformation' ]; then
     if [ -f $2/wlanInfo-01.csv ]; then rm -f $2/wlanInfo-* ; fi
     airodump-ng -w $2/wlanInfo wlan0 & sleep $3 && kill $!
     if [ -f /usr/bin/wash ]; then 
-       if [ -f $pathReaver/wpsInfo.txt ]; then rm -f $pathReaver/wpsInfo.txt ; fi
-       wash -f $2/wlanInfo-01.cap -C -o $pathReaver/wpsInfo.txt
+       if [ -f $2/wpsInfo.txt ]; then rm -f $2/wpsInfo.txt ; fi
+       wash -f $2/wlanInfo-01.cap -C -o $2/wpsInfo.txt
     fi
 fi 
 
@@ -145,17 +144,5 @@ if [ "$1" == 'reaver' ]; then
 fi 
 
 if [ "$1" == 'wash' ]; then 
-    cat $pathReaver/wpsInfo.txt | grep -e ":"
-fi 
-
-if [ "$1" == 'copyReaver' ]; then 
-    cp -pr $2/reaver $3 && chmod 755 $3/reaver && if [ -f /usr/bin/reaver ]; then rm -f /usr/bin/reaver; fi && ln -s $3/reaver /usr/bin/reaver
-fi 
-
-if [ "$1" == 'copyWash' ]; then 
-    cp -pr $2/wash $3 && chmod 755 $3/wash && if [ -f /usr/bin/wash ]; then rm -f /usr/bin/wash; fi && ln -s $3/wash /usr/bin/wash
-fi 
-
-if [ "$1" == 'copyReaverDB' ]; then 
-    cp -pr $2/reaver.db $3 && chmod 755 $3/reaver.db;
-fi 
+    cat $2/wpsInfo.txt | grep -e ":"
+fi 
\ No newline at end of file
