@@ -1,13 +1,8 @@
 #!/bin/sh
 
 # defaults
-DRIVERPATH="/opt/cleven/compat-wireless" 
 FILEPATH="/home/user/.cleven"
 
-# # Save mac address
-# MACADDR="`ifconfig wlan0 | grep wlan0 | awk -F"addr " '{print $2}' | awk -F"-" 'BEGIN {OFS = ":"}; {print $1,$2,$3,$4,$5,$6}'| awk -F" " '{print $1}'`"
-# echo $MACADDR
-
 # Read MAC address
 MACADDR="`cat $FILEPATH/myMAC`"
 echo $MACADDR
